@@ -309,7 +309,7 @@ class ConnectionPageBin(Adw.Bin):
 
             dialog.present (win)
 
-        win.maps_page_bin.goto_map_avg_first_load()
+        win.maps_page_bin.goto_map_last_seen_first_load()
 
         return GLib.SOURCE_REMOVE
 
@@ -594,7 +594,7 @@ class ConnectionPageBin(Adw.Bin):
             self.logger.warning("No Interface!")
             return
 
-        self.device_configuration_page.populate_entries(self.interface)
+        self.device_configuration_page.populate_entries(self.interface, True)
         self.connection_page_nav_view.push_by_tag("device-preferences")
 
     @Gtk.Template.Callback()
