@@ -45,6 +45,10 @@ class DeviceConfigurationPageBin(Adw.Bin):
     all_channels_button = Gtk.Template.Child()
     apply_long_short_name_button = Gtk.Template.Child()
     apply_wifi_settings_button = Gtk.Template.Child()
+    bluetooth_settings_expander_row = Gtk.Template.Child()
+    bluetooth_enabled_switch = Gtk.Template.Child()
+    bluetooth_pin_type = Gtk.Template.Child()
+    bluetooth_pin_entry = Gtk.Template.Child()
     channel_expander_row = Gtk.Template.Child()
     channel_config_button = Gtk.Template.Child()
     channel_qr = Gtk.Template.Child()
@@ -58,6 +62,7 @@ class DeviceConfigurationPageBin(Adw.Bin):
     network_settings_expander_row = Gtk.Template.Child()
     node_name_expander_row = Gtk.Template.Child()
     ntp_server_entry = Gtk.Template.Child()
+    role_selection = Gtk.Template.Child()
     primary_channel_button = Gtk.Template.Child()
     short_name_entry = Gtk.Template.Child()
     short_name_entry_button = Gtk.Template.Child()
@@ -74,17 +79,20 @@ class DeviceConfigurationPageBin(Adw.Bin):
 
     disconnection_timeout = 10000 #milliseconds
 
-    def populate_entries(self, interface):
+    def populate_entries(self, interface, reset_expanders):
         app = Gtk.Application.get_default()
         win = Gtk.Application.get_active_window(app)
         self.interface = interface
 
         node = interface.getNode('^local')
 
+        if reset_expanders:
+            self.network_settings_expander_row.set_expanded(False)
+            self.node_name_expander_row.set_expanded(False)
+            self.channel_expander_row.set_expanded(False)
+            self.bluetooth_settings_expander_row.set_expanded(False)
+
         self._clear_channel_entries()
-        self.network_settings_expander_row.set_expanded(False)
-        self.node_name_expander_row.set_expanded(False)
-        self.channel_expander_row.set_expanded(False)
         self.long_name_entry.set_text(win.nearby_nodes_page_bin.own_node.longName)
         self.short_name_entry.set_text(win.nearby_nodes_page_bin.own_node.shortName)
         self.lisensed_row.set_active(win.nearby_nodes_page_bin.own_node.isLicensed)
@@ -128,6 +136,15 @@ class DeviceConfigurationPageBin(Adw.Bin):
             self.ipv4_config_subnet.set_sensitive(True)
             self.ipv4_config_dns.set_sensitive(True)
 
+        self.bluetooth_enabled_switch.set_active(node.localConfig.bluetooth.enabled)
+        self.bluetooth_pin_type.set_selected(node.localConfig.bluetooth.mode)
+        self.bluetooth_pin_entry.set_text(str(node.localConfig.bluetooth.fixed_pin).zfill(6))
+
+        self.bluetooth_pin_type.set_sensitive(node.localConfig.bluetooth.enabled)
+        self.bluetooth_pin_entry.set_sensitive(node.localConfig.bluetooth.enabled)
+
+        self.role_selection.set_selected(node.localConfig.device.role)
+
     def set_connected_button_sensitivity(self, sensitivity):
         not_sensitivity = not sensitivity
         #Set sensitive when connected
@@ -209,7 +226,7 @@ class DeviceConfigurationPageBin(Adw.Bin):
             node = self.interface.getNode('^local')
             node.setURL(new_url)
 
-            win.channels_page_bin.reset_all_channels_and_dms(self.interface)
+            win.channels_page_bin.reset_all_channels_and_dms()
             win.channels_page_bin.populate_all_channels_and_dms(self.interface)
             GLib.timeout_add(self.disconnection_timeout, self.disconnection_event_cb)
 
@@ -308,7 +325,7 @@ class DeviceConfigurationPageBin(Adw.Bin):
 
     @Gtk.Template.Callback()
     def _reset_page_button_clicked_cb(self, button):
-        self.populate_entries(self.interface)
+        self.populate_entries(self.interface, False)
 
     def _device_config_reset_callback(self, dialog, response, user):
         app = Gtk.Application.get_default()
@@ -413,6 +430,64 @@ class DeviceConfigurationPageBin(Adw.Bin):
         win.connection_page_bin.channel_configuration_page.reset_channels()
         win.connection_page_bin.connection_page_nav_view.push_by_tag("channel-configuration")
 
+    @Gtk.Template.Callback()
+    def _apply_bluetooth_settings_clicked_cb(self, button):
+        app = Gtk.Application.get_default()
+        win = Gtk.Application.get_active_window(app)
+        node = self.interface.getNode('^local')
+
+        enable_bluetooth = self.bluetooth_enabled_switch.get_active()
+        pin_type = self.bluetooth_pin_type.get_selected()
+        pin_entry = self.bluetooth_pin_entry.get_text()
+        try:
+            int_pin_entry = int(pin_entry)
+        except:
+            self.logger.warning("Illegal Chars in PIN Entry!")
+            dialog = Adw.AlertDialog.new(_("Alert"),
+                                         _("Only put numbers in PIN Entry"))
+            dialog.add_response ("close",  _("_Close"))
+
+            dialog.present (win)
+            return
+
+        self.logger.debug("BLE Enabled: " + str(enable_bluetooth))
+        self.logger.debug("Pin type: " + str(pin_type))
+        self.logger.debug("Fixed PIN: " + str(int_pin_entry))
+
+        node.localConfig.bluetooth.enabled = enable_bluetooth
+        node.localConfig.bluetooth.mode = pin_type
+        node.localConfig.bluetooth.fixed_pin = int_pin_entry
+
+        self.logger.debug("Applying BLE Settings")
+        win.window_toast_overlay.add_toast(Adw.Toast(title="Bluetooth Settings Applied"))
+        GLib.timeout_add(self.disconnection_timeout, self.disconnection_event_cb)
+
+        node.writeConfig("bluetooth")
+
+    @Gtk.Template.Callback()
+    def _bluetooth_enabled_switch_row_notify_active_cb(self, switch_row, user):
+        app = Gtk.Application.get_default()
+        win = Gtk.Application.get_active_window(app)
+        self.logger.debug("BLE Enabled switch row switched")
+
+        self.bluetooth_pin_type.set_sensitive(self.bluetooth_enabled_switch.get_active())
+        self.bluetooth_pin_entry.set_sensitive(self.bluetooth_enabled_switch.get_active())
+
+    @Gtk.Template.Callback()
+    def _set_device_role_button_clicked_cb(self, button):
+        app = Gtk.Application.get_default()
+        win = Gtk.Application.get_active_window(app)
+        node = self.interface.getNode('^local')
+
+        role_selection = self.role_selection.get_selected()
+
+        node.localConfig.device.role = role_selection
+        node.writeConfig("device")
+
+        self.logger.debug("Applying Device Role Settings")
+        win.window_toast_overlay.add_toast(Adw.Toast(title="Device Role Setting Applied"))
+        GLib.timeout_add(self.disconnection_timeout, self.disconnection_event_cb)
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         app = Gtk.Application.get_default()
