@@ -342,9 +342,12 @@ class MessageStorage():
             new_message.append("no_text")
         #time
         if 'rxTime' in packet:
-            new_message.append(packet["rxTime"])
+            if packet["rxTime"] != 0:
+                new_message.append(packet["rxTime"])
+            else:
+                new_message.append(int(datetime.now(timezone.utc).timestamp()))
         else:
-            new_message.append(0)
+            new_message.append(int(datetime.now(timezone.utc).timestamp()))
         #delivered
         new_message.append(False)
         #channel_Title
