@@ -121,7 +121,6 @@ class NodeRow(Adw.ExpanderRow):
     def reset_node(self):
         self.set_title("Disconnected")
         self.set_subtitle("")
-        self.short_name_label.set_visible(False)
         self.other_stats.set_visible(False)
         self.device_info.set_visible(False)
         self.position.set_visible(False)
@@ -129,15 +128,15 @@ class NodeRow(Adw.ExpanderRow):
 
     def update_node_time(self):
         if hasattr(self, 'lastHeard') and self.lastHeard > 0:
-            self.other_stats.set_title("Last Heard: " + utils.getTimeAgo(self.lastHeard))
+            self.set_subtitle("Last Heard: " + utils.getTimeAgoDate(self.lastHeard))
 
     def update_node_ui(self):
         if hasattr(self, 'hwModel') and hasattr(self, 'role'):
-            self.set_subtitle("Model: " + str(self.hwModel) + ", Role: " + str(self.role))
+            self.other_stats.set_title("Model: " + str(self.hwModel) + ", Role: " + str(self.role))
         elif hasattr(self, 'hwModel'):
-            self.set_subtitle("Model: " + str(self.hwModel))
+            self.other_stats.set_title("Model: " + str(self.hwModel))
         elif hasattr(self, 'role'):
-            self.set_subtitle("Role: " + str(self.role))
+            self.other_stats.set_title("Role: " + str(self.role))
 
 
         # initializing string
@@ -153,21 +152,20 @@ class NodeRow(Adw.ExpanderRow):
         self.set_title(id_string)
 
         if hasattr(self, 'shortName'):
-            self.short_name_label.set_visible(True)
             self.short_name_label.set_label(str(self.shortName))
         else:
-            self.short_name_label.set_visible(False)
+            self.short_name_label.set_label(" ")
 
         self.other_stats.set_visible(True)
 
         if hasattr(self, 'lastHeard') and self.lastHeard > 0:
-            self.other_stats.set_title("Last Heard: " + utils.getTimeAgo(self.lastHeard))
+            self.set_subtitle("Last Heard: " + utils.getTimeAgoDate(self.lastHeard))
 
         # initializing string
         other_stats_string = ""
 
         if hasattr(self, 'uptimeSeconds'):
-            other_stats_string = other_stats_string + "Uptime (Sec): " + str(self.uptimeSeconds) + ", "
+            other_stats_string = other_stats_string + "Uptime: " + utils.getTimeAgoSec(self.uptimeSeconds) + ", "
         if hasattr(self, 'hopsAway'):
             other_stats_string = other_stats_string + "Hops Away: " + str(self.hopsAway)
         elif self.own_node:
@@ -177,8 +175,21 @@ class NodeRow(Adw.ExpanderRow):
 
         self.other_stats.set_subtitle(other_stats_string)
 
-        if hasattr(self, 'snr'):
-            self.snr_label.set_label("SNR: " + format(self.snr, '.2f'))
+        if hasattr(self, 'snr') and hasattr(self, 'rssi') :
+        # Set the SNR label with the SNR value and signal strength bars based on https://sensing-labs.com/f-a-q/a-good-radio-level/
+            if self.snr >= -7 and self.rssi >= -115:
+                signal_strength_bars = "████"  # 4 filled bars (strong signal)
+            elif self.snr >= -7 and self.rssi >= -126 or self.snr >= -15 and self.rssi >= -115 or self.snr >= -15 and self.rssi >= -126 and self.rssi >= -115 + (self.snr + 15) * -1 * (115 - 126) / (7 - 15):
+                signal_strength_bars = "███░"  # 3 filled bars (moderate signal)
+            elif self.snr >= -17.5 and self.rssi >= -130 and self.snr >= -17.5 and self.rssi > -130 + (self.snr + 15) * -5 / 2.5: 
+                signal_strength_bars = "██░░"  # 2 filled bars (weak signal)
+            elif self.snr >= -17.5 and self.rssi >= -130 and self.rssi <= -130 + (self.snr + 15) * -5 / 2.5:
+                signal_strength_bars = "█░░░"  # 1 filled bar (very weak signal)
+            else:
+                signal_strength_bars = "░░░░"  # 1 filled bar (even weaker signal)
+
+            self.snr_label.set_label("SNR: " + format(self.snr, '.2f') + "  " + signal_strength_bars)
+
 
         if not self.deviceMetricPresent:
             self.device_info.set_visible(False)
@@ -214,7 +225,7 @@ class NodeRow(Adw.ExpanderRow):
                                     "," + format(self.longitude, 'f') +
                                     "\">Lat: " + format(self.latitude, 'f') +
                                     " Lon: " + format(self.longitude, 'f') +  "</a>" +
-                                    ", Last Position time: " + utils.getTimeAgo(self.position_time))
+                                    ", Last Position time: " + utils.getTimeAgoDate(self.position_time))
         elif hasattr(self, 'latitude') and hasattr(self, 'longitude'):
             self.position.set_use_markup(True)
             self.position.set_title("<a href=\"geo:" + format(self.latitude, 'f') +
@@ -246,9 +257,9 @@ class NodeRow(Adw.ExpanderRow):
                 self.marker.set_marker_long_name_label(self.id)
 
             if hasattr(self, 'position_time'):
-                self.marker.set_marker_last_heard_label("Last Position Time: " + str(utils.getTimeAgo(self.position_time)))
+                self.marker.set_marker_last_heard_label("Last Position Time: " + str(utils.getTimeAgoDate(self.position_time)))
             elif hasattr(self, 'lastHeard') and self.lastHeard > 0:
-                self.marker.set_marker_last_heard_label("Last Heard: " + str(utils.getTimeAgo(self.lastHeard)))
+                self.marker.set_marker_last_heard_label("Last Heard: " + str(utils.getTimeAgoDate(self.lastHeard)))
 
             if self.own_node:
                 self.marker.set_marker_hops_away_label("Your Device")
@@ -265,9 +276,10 @@ class NodeRow(Adw.ExpanderRow):
             self.marker.set_location(self.latitude, self.longitude)
             if self.own_node:
                 win.maps_page_bin.goto_map_first_load(self.latitude, self.longitude)
+                win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude)
             else:
-                win.maps_page_bin.longitude_running_avg(self.longitude)
-                win.maps_page_bin.latitude_running_avg(self.latitude)
+                win.maps_page_bin.define_longitude_last_seen(self.longitude)
+                win.maps_page_bin.define_latitude_last_seen(self.latitude)
 
     def populate_node(self, node):
         if node.get('num'):
@@ -346,6 +358,9 @@ class NodeRow(Adw.ExpanderRow):
         if "rxSnr" in packet:
             self.snr = packet["rxSnr"]
 
+        if "rxRssi" in packet:
+            self.rssi = packet["rxRssi"]
+
         if 'decoded' in packet:
             if packet['decoded'].get('portnum') == 'NODEINFO_APP':
                 app = Gtk.Application.get_default()
